=================
Seaborn extension
=================

The `pesummary` package extends various `seaborn <https://github.com/mwaskom/seaborn>`_
functions/classes to provide further customisation. See below for details.

kdeplot
-------

.. literalinclude:: ../../examples/core/bounded_kdeplot.py
   :language: python

.. image:: ./examples/bounded_kdeplot.png

.. autofunction:: pesummary.core.plots.kde.kdeplot
